MethodChannelTrustdeviceProPlugin class

An implementation of TrustdeviceProPluginPlatform that uses method channels.

Inheritance

Properties

captchaCallback ↔ TDRiskCaptchaCallback?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
livenessCallback ↔ TDLivenessCallback?
getter/setter pair
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBlackBox() → Future<String>
override
getBlackBoxAsync() → Future<String>
override
getRootViewController() → Future
override
getSDKVersion() → Future<String>
override
initWithOptions(Map<String, dynamic> configMap) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showCaptcha(TDRiskCaptchaCallback callback) → Future<void>
override
showLiveness(String license, TDLivenessCallback callback) → Future<void>
override
sign(String url) → Future<Map<String, dynamic>>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited