TrustdeviceProPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • TrustdeviceProPluginPlatform
Implementers

Constructors

TrustdeviceProPluginPlatform()
Constructs a TrustdeviceProPluginPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBlackBox() → Future<String>
getBlackBoxAsync() → Future<String>
getRootViewController() → Future
getSDKVersion() → Future<String>
initWithOptions(Map<String, dynamic> configMap) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showCaptcha(TDRiskCaptchaCallback callback) → Future<void>
showLiveness(String license, TDLivenessCallback callback) → Future<void>
sign(String url) → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ TrustdeviceProPluginPlatform
The default instance of TrustdeviceProPluginPlatform to use.
getter/setter pair