TrustdeviceSePlugin class

Constructors

TrustdeviceSePlugin([dynamic behaviorCollector])
构造方法 - 传入行为采集插件实例 如果不需要行为采集,可以不传
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect({String? blackbox}) → Future<Map<String, dynamic>>
收集行为数据
getDeviceInfo() → Future<Map<String, dynamic>>
getSDKVersion() → Future<String>
Obtain the sdk version number
hasBehaviorCollector() → bool
检查是否有行为采集插件
initWithOptions(Map<String, dynamic> configMap) → Future<void>
Initialize the configuration and return to blackBox
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(String url) → Future<Map<String, dynamic>>
start() → void
开始行为采集
stop() → void
停止行为采集
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → TrustdeviceSePlugin
获取单例实例的静态方法(保持向后兼容)
no setter